@@ -11,6 +11,13 @@ from filtres.filtre_base import FiltreBase
 from signaux.signalll import Signal
 
 class FigureDynamique():
+    def dispay(self):
+        try:
+            __IPYTHON__
+            display.display(self.figure)
+        except:
+            pass
+
     def __init__(self, filtre):
         plt.ion()
         self.filtre = filtre
@@ -55,6 +62,7 @@ class FigureDynamique():
         self.axe_sortie.set_ylabel("$s$ (V)")
         # display.display(self.figure)
         # self.figure.show()
+        self.display()
 
     def mettre_a_jour(self):
         vecteur_f = [m.f for m in self.filtre._FiltreBase__liste_mesures]
@@ -94,6 +102,7 @@ class FigureDynamique():
         nom_fichier = "graphs-bode/{0}_f_{1}_Hz.pdf".format(self.filtre.lire_nom(), str(int(self.filtre.es.f)).zfill(6))
         self.figure.savefig(nom_fichier)
         # display.display(self.figure, silence=True)
+        self.display()
 
 
     def finir(self):
